@@ -1,10 +1,10 @@
-use std::str;
+use std::{str, sync::Arc};
 
 use crate::pyo_utils::py_dict_to_map;
 use pyo3::prelude::*;
 use pyo3::types::PyDict;
 use pyo3_stub_gen::derive::*;
-use statsig_rust::{log_w, DynamicValue, StatsigUser};
+use statsig_rust::{log_w, user::user_data::UserData, DynamicValue, StatsigUser};
 
 const TAG: &str = stringify!(StatsigUserPy);
 
@@ -59,25 +59,28 @@ impl StatsigUserPy {
         }
 
         let internal_user_id = user_id.clone().unwrap_or_default();
-        let mut user = StatsigUser::with_user_id(internal_user_id);
+        let mut user_data = UserData {
+            user_id: Some(DynamicValue::from(internal_user_id)),
+            ..UserData::default()
+        };
 
         if let Some(e) = email.clone() {
-            user.email = Some(DynamicValue::from(e));
+            user_data.email = Some(DynamicValue::from(e));
         }
         if let Some(i) = ip.clone() {
-            user.ip = Some(DynamicValue::from(i));
+            user_data.ip = Some(DynamicValue::from(i));
         }
         if let Some(c) = country.clone() {
-            user.country = Some(DynamicValue::from(c));
+            user_data.country = Some(DynamicValue::from(c));
         }
         if let Some(l) = locale.clone() {
-            user.locale = Some(DynamicValue::from(l));
+            user_data.locale = Some(DynamicValue::from(l));
         }
         if let Some(a) = app_version.clone() {
-            user.app_version = Some(DynamicValue::from(a));
+            user_data.app_version = Some(DynamicValue::from(a));
         }
         if let Some(u) = user_agent.clone() {
-            user.user_agent = Some(DynamicValue::from(u));
+            user_data.user_agent = Some(DynamicValue::from(u));
         }
 
         let custom_map = custom.as_ref().map(|dict| py_dict_to_map(dict.bind(py)));
@@ -88,12 +91,14 @@ impl StatsigUserPy {
             .as_ref()
             .map(|dict| py_dict_to_map(dict.bind(py)));
 
-        user.custom = custom_map;
-        user.custom_ids = custom_ids_map;
-        user.private_attributes = private_attributes_map;
+        user_data.custom = custom_map;
+        user_data.custom_ids = custom_ids_map;
+        user_data.private_attributes = private_attributes_map;
 
         Ok(Self {
-            inner: user,
+            inner: StatsigUser {
+                data: Arc::new(user_data),
+            },
             user_id,
             email,
             ip,
@@ -112,61 +117,63 @@ impl StatsigUserPy {
             "user_id" => {
                 if let Ok(Some(user_id)) = value.extract::<Option<String>>(py) {
                     self.user_id = Some(user_id.clone());
-                    self.inner.user_id = Some(DynamicValue::from(user_id.clone()));
+                    self.inner.set_user_id(user_id);
                 }
             }
             "email" => {
                 if let Ok(v) = value.extract::<Option<String>>(py) {
                     self.email = v.clone();
-                    self.inner.email = v.map(DynamicValue::from);
+                    self.inner.set_email(v);
                 }
             }
             "ip" => {
                 if let Ok(v) = value.extract::<Option<String>>(py) {
                     self.ip = v.clone();
-                    self.inner.ip = v.map(DynamicValue::from);
+                    self.inner.set_ip(v);
                 }
             }
             "country" => {
                 if let Ok(v) = value.extract::<Option<String>>(py) {
                     self.country = v.clone();
-                    self.inner.country = v.map(DynamicValue::from);
+                    self.inner.set_country(v);
                 }
             }
             "locale" => {
                 if let Ok(v) = value.extract::<Option<String>>(py) {
                     self.locale = v.clone();
-                    self.inner.locale = v.map(DynamicValue::from);
+                    self.inner.set_locale(v);
                 }
             }
             "app_version" => {
                 if let Ok(v) = value.extract::<Option<String>>(py) {
                     self.app_version = v.clone();
-                    self.inner.app_version = v.map(DynamicValue::from);
+                    self.inner.set_app_version(v);
                 }
             }
             "user_agent" => {
                 if let Ok(v) = value.extract::<Option<String>>(py) {
                     self.user_agent = v.clone();
-                    self.inner.user_agent = v.map(DynamicValue::from);
+                    self.inner.set_user_agent(v);
                 }
             }
             "custom_ids" => {
                 if let Ok(dict) = value.extract::<Option<Py<PyDict>>>(py) {
-                    self.inner.custom_ids = dict.as_ref().map(|d| py_dict_to_map(d.bind(py)));
+                    let mut_data = Arc::make_mut(&mut self.inner.data);
+                    mut_data.custom_ids = dict.as_ref().map(|d| py_dict_to_map(d.bind(py)));
                     self.custom_ids = dict;
                 }
             }
             "custom" => {
                 if let Ok(dict) = value.extract::<Option<Py<PyDict>>>(py) {
-                    self.inner.custom = dict.as_ref().map(|d| py_dict_to_map(d.bind(py)));
+                    let mut_data = Arc::make_mut(&mut self.inner.data);
+                    mut_data.custom = dict.as_ref().map(|d| py_dict_to_map(d.bind(py)));
                     self.custom = dict;
                 }
             }
             "private_attributes" => {
                 if let Ok(dict) = value.extract::<Option<Py<PyDict>>>(py) {
-                    self.inner.private_attributes =
-                        dict.as_ref().map(|d| py_dict_to_map(d.bind(py)));
+                    let mut_data = Arc::make_mut(&mut self.inner.data);
+                    mut_data.private_attributes = dict.as_ref().map(|d| py_dict_to_map(d.bind(py)));
                     self.private_attributes = dict;
                 }
             }
