@@ -1,5 +1,5 @@
 use crate::evaluation::evaluator_result::EvaluatorResult;
-use crate::spec_types::Spec;
+use crate::specs_response::spec_types::Spec;
 use crate::StatsigUser;
 use serde_json::Value;
 use std::collections::HashMap;
@@ -34,9 +34,15 @@ pub trait OverrideAdapter: Send + Sync {
         result: &mut EvaluatorResult<'_>,
     ) -> bool;
 
-    fn override_gate(&self, key: &str, value: bool);
-    fn override_dynamic_config(&self, key: &str, value: HashMap<String, Value>);
-    fn override_experiment(&self, key: &str, value: HashMap<String, Value>);
-    fn override_experiment_by_group_name(&self, key: &str, group_name: &str);
-    fn override_layer(&self, key: &str, value: HashMap<String, Value>);
+    fn override_gate(&self, key: &str, value: bool, id: Option<&str>);
+    fn override_dynamic_config(&self, key: &str, value: HashMap<String, Value>, id: Option<&str>);
+    fn override_experiment(&self, key: &str, value: HashMap<String, Value>, id: Option<&str>);
+    fn override_experiment_by_group_name(&self, key: &str, group_name: &str, id: Option<&str>);
+    fn override_layer(&self, key: &str, value: HashMap<String, Value>, id: Option<&str>);
+
+    fn remove_gate_override(&self, key: &str, id: Option<&str>);
+    fn remove_dynamic_config_override(&self, key: &str, id: Option<&str>);
+    fn remove_experiment_override(&self, key: &str, id: Option<&str>);
+    fn remove_layer_override(&self, key: &str, id: Option<&str>);
+    fn remove_all_overrides(&self);
 }
